Method: Thread::Pool#initialize

Defined in:
lib/thread/pool.rb

#initialize(min, max = nil, &block) ⇒ Pool

Create the pool with minimum and maximum threads.

The pool will start with the minimum amount of threads created and will spawn new threads until the max is reached in case of need.

A default block can be passed, which will be used to #process the passed data.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/thread/pool.rb', line 112

def initialize (min, max = nil, &block)
  @min   = min
  @max   = max || min
  @block = block

  @cond  = ConditionVariable.new
  @mutex = Mutex.new

  @done       = ConditionVariable.new
  @done_mutex = Mutex.new

  @todo     = []
  @workers  = []
  @timeouts = {}

  @spawned       = 0
  @waiting       = 0
  @shutdown      = false
  @trim_requests = 0
  @auto_trim     = false
  @idle_trim     = nil

  @mutex.synchronize {
    min.times {
      spawn_thread
    }
  }
end